Changelog
=========

Unreleased
----------
*No changes yet.*

v0.9
----
*Released on 2019-02-21*

  - Enabled `Loop Controls <http://jinja.pocoo.org/docs/2.10/templates/#loop-controls>`_
    and `Expression Statement <http://jinja.pocoo.org/docs/2.10/templates/#expression-statement>`_
    extensions.
  - Added documentation with `ReadTheDocs <https://tpl.readthedocs.io/>`_
    integration and a manpage. This includes a fix for `#8
    <https://github.com/M3t0r/tpl/issues/8>`_.
  - Added changelog with old releases.
  - Include auxilliary files in the source distribution generated by
    setuptools.
  - Reformatted README.

v0.8
----
*Released on 2018-10-27*

  - Added support for Python 3.5.
  - Added link to `Jinja2 template designer documentation
    <http://jinja.pocoo.org/docs/templates/>`_ in ``--help`` output thanks to
    `@loudambiance <https://github.com/loudambiance>`_.
  - Changed a decent amount of building code with help from `@mre
    <https://github.com/mre>`_.
  - Added CI with `travis-ci <https://travis-ci.com/M3t0r/tpl>`_.
  - Use Pipfile instead of requirements.txt for the development environment.
  - Fixed ``-v`` option in Docker image.

v0.7
----
*Released on 2018-07-17*

  - Instead of simply updating only the top level dict we now merge
    dictionaries on all levels.
  - Added support for lists and scalar values a root level of data sources.
  - Added automated builds for Dockerhub

v0.6.2
------
*Released on 2018-07-16*

  - First release to `PyPI <https://pypi.org/project/tpl/>`_.

v0.6.1
------
*Released on 2018-07-16*

  - Fix release target in Makefile.

v0.6
----
*Released on 2018-07-16*

  - Generated version numbers now adhere to PEP 440.

v0.5
----
*Released on 2018-07-12*

  - Added new CLI end-to-end test suit.
  - Improved Docker image.
  - Printing usage and help texts to ``STDERR`` instead of ``STDOUT``.

v0.4
----
*Released on 2018-07-01*

  - Improved ``--help`` message with option explanations.
  - Added usage text to README.

v0.3
----
*Released on 2018-07-01*

  - Use a multistage Dockerfile.

v0.2
----
*Released on 2018-06-29*

  - Add Dockerfile together with
    `Docker hub <https://hub.docker.com/r/m3t0r/tpl/>`_ integration.
  - Forcefully end every render in a newline. Previously newlines at the end
    were dropped by Jinja.
  - Fixed installation not working.

v0.1
----
*Released on 2018-06-29*

Initial commit & release.
